@@ -1,16 +1,18 @@
-# All Rights Reserved.
 #
-#    Licensed under the Apache License, Version 2.0 (the "License"); you may
-#    not use this file except in compliance with the License. You may obtain
-#    a copy of the License at
+# Copyright (c) 2019, 2020 Oracle and/or its affiliates. All rights reserved.
 #
-#         http://www.apache.org/licenses/LICENSE-2.0
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 #
-#    Unless required by applicable law or agreed to in writing, software
-#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-#    License for the specific language governing permissions and limitations
-#    under the License.
 
 import io
 import logging
@@ -18,6 +20,7 @@ import os
 import sys
 
 from fdk import constants
+from fdk import log
 
 from fdk.async_http import response
 
@@ -36,13 +39,13 @@ def event_handle(handle_code):
     """
     async def pure_handler(request):
         from fdk import runner
-        logger.info("in pure_handler")
+        log.log("in pure_handler")
         headers = dict(request.headers)
         log_frame_header(headers)
         func_response = await runner.handle_request(
             handle_code, constants.HTTPSTREAM,
             headers=headers, data=io.BytesIO(request.body))
-        logger.info("request execution completed")
+        log.log("request execution completed")
 
         headers = func_response.context().GetResponseHeaders()
         status = func_response.status()
